#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-6kS0pFpX8HfLUC1GhOkg27
key:                  persistent-mysql-2.13.1.5-6kS0pFpX8HfLUC1GhOkg27
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  58a663cbda7a88a688d41fbe874c983e
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-6kS0pFpX8HfLUC1GhOkg27
depends:
    aeson-2.2.2.0-CRLoVrOByflKEQQ5tNkVEn base-4.18.2.1
    blaze-builder-0.4.4.1-8H0R0umV9po1kAX8f2JboT bytestring-0.11.5.3
    conduit-1.3.6.1-3ZkfU3UFxE9HTVkK8cD containers-0.6.7
    monad-logger-0.3.42-LOVOH15E4izKhi87BCMM5A
    mysql-0.2.1-8OOLa5L8J6UH8WlbUmTWle
    mysql-simple-0.4.9-IQfNecyrScGG7Xwe3pqiXL
    persistent-2.14.5.2-J5QcwNMWHDSIesY2UvDstY
    resource-pool-0.2.3.2-56FvAIeSiW7Im0pzVjCOLr
    resourcet-1.2.6-ISzbKkOS7tA59m6DqAPsM text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

